@@ -303,37 +303,6 @@ class BinhostsBase(Cachable):
             self.host = host
             self.parent = parent
             self.timestamp_file = path.join(self.host, self.parent.ts_path)
-            # try:
-            #     self.timestamp_file = path.join(self.host, self.parent.ts_path)
-            #     #self.timestamp = self.parent._get_timestamp(timestamp_file)
-            #     #self.duration = int((time.time() - start_ts) * 1000)
-            #     self.timestamp = 0
-            #     self.duration = 10000000
-            #     # self.outdated = int(start_ts) - self.timestamp > parent.actual_period
-            #     # self.downgraded = self.timestamp < parent.last_ts
-            #
-            #     fn, data = self.parent.fetch_envdata(self.host)
-            #     if fn:
-            #         cp = ConfigParserCaseSens()
-            #         try:
-            #             cp.read_string(data)
-            #             if "update" in cp.sections():
-            #                 self._level = int(cp["update"]["level"])
-            #             else:
-            #                 self._level = None
-            #         except (CPError, KeyError) as e:
-            #             self._level = None
-            #     else:
-            #         self._level = None
-            # except BaseException as e:
-            #     if isinstance(e, KeyboardInterrupt):
-            #         raise
-            #     self.timestamp = 0
-            #     self.duration = 0
-            #     self.outdated = True
-            #     self.downgraded = True
-            #     self._level = 0
-
 
         async def init(self):
             try:
@@ -343,20 +312,21 @@ class BinhostsBase(Cachable):
                     raise ValueError
                 self.outdated = int(start_ts) - int(self.timestamp) > self.parent.actual_period
                 self.downgraded = self.timestamp < self.parent.last_ts
-                fn, data = await self.parent.async_fetch_envdata(self.host)
-                if fn:
-                    cp = ConfigParserCaseSens()
-                    try:
-                        cp.read_string(data)
-                        if "update" in cp.sections():
-                            self._level = int(cp["update"]["level"])
-                        else:
+                if self.timestamp:
+                    fn, data = await self.parent.async_fetch_envdata(self.host)
+                    if fn:
+                        cp = ConfigParserCaseSens()
+                        try:
+                            cp.read_string(data)
+                            if "update" in cp.sections():
+                                self._level = int(cp["update"]["level"])
+                            else:
+                                self._level = None
+                        except (CPError, KeyError) as e:
                             self._level = None
-                    except (CPError, KeyError) as e:
+                    else:
                         self._level = None
-                else:
-                    self._level = None
-                return self
+                    return self
             except BaseException as e:
                 if isinstance(e, KeyboardInterrupt):
                     raise
